==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-textedit/i18n/l-te_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ColorDialog</name>
    <message>
        <location filename="../ColorDialog.ui" line="14"/>
        <source>Customize Colors</source>
        <translation>Přizpůsobit barvy</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="24"/>
        <source>Item Type</source>
        <translation>Typ položky</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="29"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="34"/>
        <source>Sample</source>
        <translation>Vzorek</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="44"/>
        <location filename="../ColorDialog.cpp" line="55"/>
        <source>Select Color</source>
        <translation>Vyberte barvu</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="64"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="71"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
</context>
<context>
    <name>DnDTabBar</name>
    <message>
        <location filename="../DnDTabBar.h" line="43"/>
        <source>Detach Tab</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="17"/>
        <source>MainWindow</source>
        <translation>Hlavní okno</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="66"/>
        <source>Find the previous match</source>
        <translation>Najít předchozí shodu</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="69"/>
        <location filename="../MainUI.ui" line="82"/>
        <location filename="../MainUI.ui" line="133"/>
        <location filename="../MainUI.ui" line="146"/>
        <location filename="../MainUI.ui" line="158"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="168"/>
        <source>Find:</source>
        <translation>Najít:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="79"/>
        <source>Find the next match</source>
        <translation>Najít další shodu</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="89"/>
        <source>Replace:</source>
        <translation>Nahradit:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="108"/>
        <source>Match case</source>
        <translation>Rozlišovat velikost písmen</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="130"/>
        <source>Replace next match</source>
        <translation>Nahradit další výskyt</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="143"/>
        <source>Replace all matches (to end of document)</source>
        <translation>Nahradit všechny shody (až nakonec dokumentu)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="155"/>
        <source>Hide the find/replace options</source>
        <translation>Skrýt volby pro najít/nahradit</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="196"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="209"/>
        <source>View</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="213"/>
        <source>Syntax Highlighting</source>
        <translation>Zvýraznění syntaxe</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="220"/>
        <source>Tabs Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="237"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="252"/>
        <source>toolBar</source>
        <translation>nástrojová lišta</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="278"/>
        <source>Show Line Numbers</source>
        <translation>Zobrazit čísla řádků</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="283"/>
        <source>None</source>
        <translation>Nic</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="288"/>
        <location filename="../MainUI.cpp" line="188"/>
        <source>New File</source>
        <translation>Nový soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="291"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="299"/>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="302"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="310"/>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="313"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="321"/>
        <source>Save File As</source>
        <translation>Uložit soubor jako</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="326"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="329"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="337"/>
        <source>Close File</source>
        <translation>Zavřít soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="340"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="348"/>
        <source>Customize Colors</source>
        <translation>Přizpůsobit barvy</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="359"/>
        <source>Wrap Lines</source>
        <translation>Zalamovat řádky</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="364"/>
        <source>Find</source>
        <translation>Najít</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="367"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="375"/>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="378"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="392"/>
        <source>Show Popup Warnings</source>
        <translation>Ukázat vyskakovací varování</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="395"/>
        <location filename="../MainUI.ui" line="398"/>
        <source>Show warnings about unsaved changes</source>
        <translation>Ukázat varování o neuložených změnách</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="409"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="417"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="425"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="433"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="62"/>
        <source>Text Editor</source>
        <translation>Textový editor</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="195"/>
        <source>Open File(s)</source>
        <translation>Otevřít soubor(y)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="195"/>
        <source>Text Files (*)</source>
        <translation>Textové soubory (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="366"/>
        <location filename="../MainUI.cpp" line="377"/>
        <location filename="../MainUI.cpp" line="485"/>
        <source>Lose Unsaved Changes?</source>
        <translation>Ztratit neuložené změny?</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="366"/>
        <location filename="../MainUI.cpp" line="377"/>
        <source>This file has unsaved changes.
Do you want to close it anyway?

%1</source>
        <translation>Tento soubor má neuložené změny.
Přesto jej chcete zavřít?

%1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="485"/>
        <source>There are unsaved changes.
Do you want to close the editor anyway?

%1</source>
        <translation>Jsou tu neuložené změny.
Přesto chcete editor zavřít?

%1</translation>
    </message>
</context>
<context>
    <name>PlainTextEditor</name>
    <message>
        <location filename="../PlainTextEditor.cpp" line="110"/>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="110"/>
        <source>Text File (*)</source>
        <translation>Textový soubor (*)</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="318"/>
        <source>Row Number: %1, Column Number: %2</source>
        <translation>Řádek číslo: %1, sloupec číslo: %2</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="327"/>
        <source>The following file has been changed by some other utility. Do you want to re-load it?</source>
        <translation>Následující soubor byl změněn jiným programem. Chcete jej nahrát znovu?</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="329"/>
        <source>(Note: You will lose all currently-unsaved changes)</source>
        <translation>(Poznámka: Ztratíte všechny nyní neuložené změny)</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="333"/>
        <source>File Modified</source>
        <translation>Soubor změněn</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/desktop-utils/lumina-textedit/i18n/l-te_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>ColorDialog</name>
    <message>
        <location filename="../ColorDialog.ui" line="14"/>
        <source>Customize Colors</source>
        <translation>Přizpůsobit barvy</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="24"/>
        <source>Item Type</source>
        <translation>Typ položky</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="29"/>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="34"/>
        <source>Sample</source>
        <translation>Ukázka</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="44"/>
        <location filename="../ColorDialog.cpp" line="55"/>
        <source>Select Color</source>
        <translation>Vybrat barvu</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="64"/>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <location filename="../ColorDialog.ui" line="71"/>
        <source>Apply</source>
        <translation>Použít</translation>
    </message>
</context>
<context>
    <name>DnDTabBar</name>
    <message>
        <location filename="../DnDTabBar.h" line="43"/>
        <source>Detach Tab</source>
        <translation>Odpojit kartu</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="63"/>
        <source>Find the previous match</source>
        <translation>Najít předchozí shodu</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="66"/>
        <location filename="../MainUI.ui" line="79"/>
        <location filename="../MainUI.ui" line="130"/>
        <location filename="../MainUI.ui" line="143"/>
        <location filename="../MainUI.ui" line="155"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="165"/>
        <source>Find:</source>
        <translation>Najít:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="76"/>
        <source>Find the next match</source>
        <translation>Najít další shodu</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="86"/>
        <source>Replace:</source>
        <translation>Nahradit:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="105"/>
        <source>Match case</source>
        <translation>Rozlišovat velikost písmen</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="127"/>
        <source>Replace next match</source>
        <translation>Nahradit další výskyt</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="140"/>
        <source>Replace all matches (to end of document)</source>
        <translation>Nahradit všechny shody (až do konce dokumentu)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Hide the find/replace options</source>
        <translation>Skrýt volby pro najít/nahradit</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="193"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="207"/>
        <source>View</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="211"/>
        <source>Syntax Highlighting</source>
        <translation>Zvýrazňovat syntaxi</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Tabs Location</source>
        <translation>Umístění karet</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="235"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="273"/>
        <source>Show Line Numbers</source>
        <translation>Zobrazovat čísla řádků</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="278"/>
        <source>None</source>
        <translation>Žádný</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="283"/>
        <location filename="../MainUI.cpp" line="192"/>
        <source>New File</source>
        <translation>Nový soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="286"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="294"/>
        <source>Open File</source>
        <translation>Otevřít soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="297"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="305"/>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="308"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="316"/>
        <source>Save File As</source>
        <translation>Uložit soubor jako</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="321"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="324"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="332"/>
        <source>Close File</source>
        <translation>Zavřít soubor</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="335"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="343"/>
        <source>Customize Colors</source>
        <translation>Přizpůsobit barvy</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="354"/>
        <source>Wrap Lines</source>
        <translation>Zalamovat řádky</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="359"/>
        <source>Find</source>
        <translation>Najít</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="362"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="370"/>
        <source>Replace</source>
        <translation>Nahradit</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="373"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="387"/>
        <source>Show Popup Warnings</source>
        <translation>Zobrazovat vyskakovací varování</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="390"/>
        <location filename="../MainUI.ui" line="393"/>
        <source>Show warnings about unsaved changes</source>
        <translation>Zobrazovat varování o neuložených změnách</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="404"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="412"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="420"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="428"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="433"/>
        <source>Print</source>
        <translation>Tisk</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="436"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="64"/>
        <source>Text Editor</source>
        <translation>Textový editor</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="199"/>
        <source>Open File(s)</source>
        <translation>Otevřít soubory</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="199"/>
        <source>Text Files (*)</source>
        <translation>Textové soubory (*)</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="252"/>
        <source>Print Content</source>
        <translation>Vytisknout obsah</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="383"/>
        <location filename="../MainUI.cpp" line="394"/>
        <source>Lose Unsaved Changes?</source>
        <translation>Ztratit neuložené změny?</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="383"/>
        <location filename="../MainUI.cpp" line="394"/>
        <source>This file has unsaved changes.
Do you want to close it anyway?

%1</source>
        <translation>Tento soubor má neuložené změny.
Přesto jej chcete zavřít?

%1</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="503"/>
        <source>Save Changes before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="503"/>
        <source>There are unsaved changes.
Do you want save them before you close the editor?

%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PlainTextEditor</name>
    <message>
        <location filename="../PlainTextEditor.cpp" line="110"/>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="110"/>
        <source>Text File (*)</source>
        <translation>Textový soubor (*)</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="318"/>
        <source>Row Number: %1, Column Number: %2</source>
        <translation>Řádek číslo: %1, sloupec číslo: %2</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="327"/>
        <source>The following file has been changed by some other utility. Do you want to re-load it?</source>
        <translation>Následující soubor byl změněn jiným programem. Chcete jej načíst znovu?</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="329"/>
        <source>(Note: You will lose all currently-unsaved changes)</source>
        <translation>(Poznámka: Ztratíte všechny doposud neuložené změny)</translation>
    </message>
    <message>
        <location filename="../PlainTextEditor.cpp" line="333"/>
        <source>File Modified</source>
        <translation>Soubor byl změněn</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
